package core.services;

import core.api.models.timemanager.tasks.TaskFieldInfo;
import core.entities.timemanager.Task;
import core.entities.timemanager.Taskgroup;
import core.repositories.timemanager.TaskRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Collection;
import java.util.List;

@Service
public class TaskService {

    private final TaskRepository taskRepository;

    public TaskService(@Autowired TaskRepository taskRepository) {
        this.taskRepository = taskRepository;
    }

    public ServiceResult<Task> createTask(Taskgroup taskgroup, TaskFieldInfo taskFieldInfo) {
        if(existTaskByName(taskgroup.getTasks(), taskFieldInfo.getTaskName())) {
            return new ServiceResult<>(ServiceExitCode.ENTITY_ALREADY_EXIST);
        }


        Task task = new Task(taskgroup, taskFieldInfo.getTaskName(), taskFieldInfo.getStartDate(), taskFieldInfo.getDeadline(), taskFieldInfo.getEta());
        taskgroup.getTasks().add(task);
        taskRepository.save(task);

        return new ServiceResult<>(task);
    }

    private boolean existTaskByName(Collection<Task> tasks, String name) {
        for(Task task : tasks) {
            if(task.getTaskName().equals(name)) {
                return true;
            }
        }
        return false;
    }
}
