import {ChangeDetectorRef, Component, OnInit} from '@angular/core';
import {UserInfo, UsersService} from "../../../api";
import {MatDialog} from "@angular/material/dialog";
import {LoginComponent} from "../../auth/login/login.component";
import {DeleteConfirmationComponent} from "./delete-confirmation/delete-confirmation.component";
import {CollectionViewer, DataSource} from "@angular/cdk/collections";
import {Observable} from "rxjs";
import {MatTableDataSource} from "@angular/material/table";
import {EditComponent} from "./edit/edit.component";
import {EditData} from "./edit/edit-data";


@Component({
  selector: 'app-usermanagement',
  templateUrl: './usermanagement.component.html',
  styleUrls: ['./usermanagement.component.css']
})
export class UsermanagementComponent implements OnInit {
  displayedColumns: string[] = ['username', 'email', 'admin', 'edit', 'delete'];
  userInfos: UserInfo[] = []
  dataSource = new MatTableDataSource(this.userInfos);

  constructor(
    public userService: UsersService,
    private dialog: MatDialog
  ) { }

  ngOnInit(): void {
    this.userService.usersGet().subscribe((result: UserInfo[]) => {
      this.userInfos = result
      this.dataSource = new MatTableDataSource<UserInfo>(this.userInfos)
    })
  }

  openDeleteConfirmation(user: UserInfo) {
    const dialogRef = this.dialog.open(DeleteConfirmationComponent, {data: user})
    return dialogRef.afterClosed().subscribe(result => {
      console.log(user.username + " has been removed!")
      const index: number = this.userInfos.indexOf(result);
      if(index !==-1) {
        console.log(this.userInfos);
        this.userInfos.splice(index, 1);
        console.log(this.userInfos);
        this.dataSource = new MatTableDataSource<UserInfo>(this.userInfos);
      }
    })
  }

  openEditDialog(user: UserInfo) {
    let counter = 0;
    for (let i = 0; i < this.userInfos.length; i++) {
      if(this.userInfos[i].admin) {
        counter ++;
      }

      if(counter == 2) {
        break;
      }
    }

    const editData: EditData = {
      username: user.username,
      email: user.email,
      admin: user.admin,
      lastadmin: counter <2
    }

    const dialogRef = this.dialog.open(EditComponent, {data: editData})
    return dialogRef.afterClosed().subscribe(result => {
      if(result !== undefined) {
        this.userInfos[this.userInfos.indexOf(user)] = result;
        this.dataSource = new MatTableDataSource<UserInfo>(this.userInfos);
      }
    })
  }

  openAddDialog() {
    const dialogRef = this.dialog.open(EditComponent, {})
    return dialogRef.afterClosed().subscribe(result => {
      if(result !== undefined) {
        this.userInfos.push(result);
        this.dataSource = new MatTableDataSource<UserInfo>(this.userInfos);
      }
    })
  }
}
